---
layout: collection
title: Design Your Network - Wireless Challenges
site_section: docs
description: An activity to think about wireless issues that come up, to help improve network planning and troubleshooting.
pdf: cck/networking/Wireless_Challenges.pdf
files:
 "Documents Français (.zip)" /files/cck/networking/Defis_sans_fil_documents.zip
 "Production files" /files/cck/networking/Wireless-Challenges-production-files.zip
created: 2013-11-04
changed: 2015-04-15
post_author: Andy Gunn
lang: en
---

![Wireless Challenges intro graphic](/files/CCK_Wireless_Challenges_intro_graphic.png "Intro graphic")

## Introduction

To continue planning our networks, you will need to know a bit more about how wireless signals work. All wireless signals are affected by the environment around us—the walls and windows of your house or office, the trees and rain, other wireless signals, and sometimes microwave ovens!

This activity takes you through a set of wireless challenges to solve on your own or as a group. It is intended to follow [Design your Network: Every Network Tells a Story](/docs/cck/planning/design-your-network-every-network-tells-story), but it can stand alone as well.

If you are working through the problem sets alone, it may take between 20 and 40 minutes, depending on how thorough you are with your solutions! As a group, it will take longer—probably closer to an hour.

### MATERIALS + SUPPLIES NEEDED

[Wireless Challenges Presentation](/files/cck/networking/Wireless_Challenges_Presentation.pdf "Wireless Challenges Presentation") - Either printed as a handout, or introduction to a group activity.
![Presentation download image](/files/CCK_Wireless_Challenges_presentation_download.png)

[Problem Scenario Worksheets](/files/cck/networking/Problem_Scenario_Workbook.pdf) - printed out on 8½ by 11” or A4 paper.
![Problem worksheets download image](/files/CCK_Wireless_Challenges_flashcard_download.png)

[Example Solutions to Problem Scenarios](/files/cck/networking/Example_Solutions_to_Wireless_Challenges_Workbook.pdf) - printed out on 8½ by 11” or A4 paper.
![Example solutions download image](/files/CCK_Wireless_Challenges_flashcard_download.png)

(Optional) Router graphics from the [Every Network Tells a Story](/docs/cck/planning/design-your-network-every-network-tells-story) packet.

A surface to work on (preferably a table so people with mobility challenges can participate comfortably).

Pens or color markers.


## Scenarios and Flashcards

This guide goes through a set of scenarios that show and describe common challenges that come up when building wireless networks. Each scenario is presented as a flashcard: a problem is shown on one page, and one or more possible solutions are shown on the pages that follow.

The set of flashcards can be used in two ways:

**1. As individual examples that you can read through and learn from.** In this format, you should print out the set of problems and solutions and go through them one by one. For each problem, draw the solution you think will solve the wireless challenge. Then compare your answer to the examples we provide on the following pages.

**2. As printouts that you or others can work through as a group.** In this format, you should print out multiple copies of just the problems (or set aside the solutions for later). Hand out the stack of problem flashcards, and work through each one in a group, in small groups or pairs, or as individuals. Then come back together and compare solutions with each other, and with the example solutions provided.

If you are working through the wireless challenges as a group, you can use the [presentation](/files/cck/networking/3-CCK-Networking-Wireless_Challenges_Presentation.pdf) to introduce the concept, and go through the rules that are also presented below.


## What are the Wireless Challenges?

Each scenario presents a specific challenge or problem that comes up when working with wireless equipment. They are categorized as:

**Distance** — Wireless signals lose power the further they travel, no matter the type of antenna.
![Distance graphic](/files/CCK_Wireless_Challenges_distance.png)

**Line of Sight** — Wireless signals can encounter total barriers, preventing connections.
![Line of sight graphic](/files/CCK_Wireless_Challenges_line_of_sight.png)

**Barriers** — Wireless signals lose signal strength through solid objects.
![Barriers graphic](/files/CCK_Wireless_Challenges_barriers.png)

**Interference** — Routers can be too loud, making it impossible for them to hear each other.
![Interference graphic](/files/CCK_Wireless_Challenges_wireless_interference.png)

**Weather** — Weather conditions can disrupt wireless signals.
![Weather graphic](/files/CCK_Wireless_Challenges_weather.png)

**Electrical power issues** — Routers need steady electricity to work correctly.
![Electrical power issues graphics](/files/CCK_Wireless_Challenges_power_issues.png)


## Going through the Wireless Challenges

The Wireless Challenge Problem and Solution sets can be studied at your own pace, if you are going through them on your own. Download the PDF of [problems](/files/cck/networking/Problem_Scenario_Workbook.pdf) and [solutions](/files/cck/networking/Example_Solutions_to_Wireless_Challenges_Workbook.pdf), then go through each scenario one by one. Draw the solution to the problem presented in each case, and then compare your solution to the examples on the pages following. No cheating!

If you are working as a group, we suggest this activity:
* Print out just the "Problem" pages, or set aside the "Solution" pages for later.
* Break in to small groups or pairs, or work individually.
* The small groups draw solutions on each flashcard, and save them until everyone is finished.
* The groups then compare the solutions with each other, and finally with the example solutions provided.

Keep in mind, there are many possible solutions to the Wireless Challenges presented here. The examples shown are just one or two options. If you think of new solutions, or think we have made a mistake somewhere, please let us know! Get in touch using the [feedback form](https://github.com/communitytechnology/communitytechnology.github.io/issues/new?title=/docs/cck/networking/wireless-challenges/).


## Rules for Solving the Challenges

When you go through the Wireless Challenges, there are a few guidelines for how to read the connections between nodes, and how to draw your own.

**Wireless link quality** — Solid or dashed lines show the strength of the link between two nodes. A solid green line is best; a dashed yellow line is okay; and a dotted pink or red line is a bad or broken link.
![Signal quality rules](/files/WirelessChallenges-Rules-signal-quality.png)

**Wireless signal strength** — Routers have different speaking and listening powers.
![Power level rules](/files/CCK_Wireless_Challenges_power_levels_rules_2.png)

**Appropriate power levels** — Due to the different speaking and listening powers, choose routers carefully. It is important to use the lowest power router that creates a good link. Using routers that have too much speaking power can cause interference.
![Power level rules 2](/files/CCK_Wireless_Challenges_power_levels_rules.png)

**Links over long distance** — Some links will need routers that have more power to reach further.
![Distance rules](/files/CCK_Wireless_Challenges_distance_rules.png)

That's it! Try the problem scenarios out for yourself.


## Definitions

**Interference**
Anything which changes or disrupts a signal as it travels along a channel between a source and a receiver. In the case of wireless, this typically refers to other signals or noise that the router needs to filter out when listening for other signals.


## Related Information

This module is intended to come immediately after [Design your Network: Every Network Tells a Story](/docs/cck/planning/design-your-network-every-network-tells-story). It should also lead in to [Learn Wireless Basics](/docs/cck/networking/learn-wireless-basics/). The sequence is designed to take communities or individuals from planning a network, through learning about common problems, to specifics about how wireless signals and equipment work.
